Skip to content
Open
Show file tree
Hide file tree
Changes from all commits
Commits
File filter

Filter by extension

Filter by extension

Conversations
Failed to load comments.
Loading
Jump to
Jump to file
Failed to load files.
Loading
Diff view
Diff view
2 changes: 1 addition & 1 deletion 3rdparty/cutlass
Submodule cutlass updated 4051 files
Original file line number Diff line number Diff line change
Expand Up @@ -602,7 +602,7 @@ __launch_bounds__(512, 1) __global__ static void group_row_col_rht_gemm_device_g

mma.accumulate_ = UMMA::ScaleOut::Zero;

tmem_allocator.allocate(TmemAllocator::Sm100TmemCapacityColumns,
tmem_allocator.allocate(cute::TMEM::Sm100TmemCapacityColumns,
&shared_storage.tmem_base_ptr);
__syncwarp();
tmem_allocation_result_barrier.arrive();
Expand Down Expand Up @@ -651,7 +651,7 @@ __launch_bounds__(512, 1) __global__ static void group_row_col_rht_gemm_device_g
} while (scheduler.is_valid());
tmem_allocator.release_allocation_lock();
accumulator_pipeline.producer_tail(accumulator_pipe_producer_state);
tmem_allocator.free(tmem_base_ptr, TmemAllocator::Sm100TmemCapacityColumns);
tmem_allocator.free(tmem_base_ptr, cute::TMEM::Sm100TmemCapacityColumns);
}
} else if (is_sched_warp) {
// Scheduler warp manages tile assignment and pipeline progress for warps
Expand Down
Original file line number Diff line number Diff line change
Expand Up @@ -407,8 +407,7 @@ __global__ static void group_rht_gemm_device(
} else if (is_mma_warp) {
mma.accumulate_ = UMMA::ScaleOut::Zero;

tmem_allocator.allocate(TmemAllocator::Sm100TmemCapacityColumns,
&shared_storage.tmem_base_ptr);
tmem_allocator.allocate(cute::TMEM::Sm100TmemCapacityColumns, &shared_storage.tmem_base_ptr);
__syncwarp();
tmem_allocation_result_barrier.arrive();
uint32_t tmem_base_ptr = shared_storage.tmem_base_ptr;
Expand Down Expand Up @@ -453,7 +452,7 @@ __global__ static void group_rht_gemm_device(
} while (tile_idx_m < tiles_in_m && tile_idx_n < tiles_in_n);
tmem_allocator.release_allocation_lock();
accumulator_pipeline.producer_tail(accumulator_pipe_producer_state);
tmem_allocator.free(tmem_base_ptr, TmemAllocator::Sm100TmemCapacityColumns);
tmem_allocator.free(tmem_base_ptr, cute::TMEM::Sm100TmemCapacityColumns);
} else if (is_epilogue_warp) {
static constexpr int FragmentSize = 256 / sizeof_bits_v<TC>;

Expand Down
Original file line number Diff line number Diff line change
Expand Up @@ -590,7 +590,7 @@ __launch_bounds__(512, 1) __global__ static void group_row_col_rht_gemm_device(

mma.accumulate_ = UMMA::ScaleOut::Zero;

tmem_allocator.allocate(TmemAllocator::Sm100TmemCapacityColumns,
tmem_allocator.allocate(cute::TMEM::Sm100TmemCapacityColumns,
&shared_storage.tmem_base_ptr);
__syncwarp();
tmem_allocation_result_barrier.arrive();
Expand Down Expand Up @@ -639,7 +639,7 @@ __launch_bounds__(512, 1) __global__ static void group_row_col_rht_gemm_device(
} while (scheduler.is_valid());
tmem_allocator.release_allocation_lock();
accumulator_pipeline.producer_tail(accumulator_pipe_producer_state);
tmem_allocator.free(tmem_base_ptr, TmemAllocator::Sm100TmemCapacityColumns);
tmem_allocator.free(tmem_base_ptr, cute::TMEM::Sm100TmemCapacityColumns);
}
} else if (is_sched_warp) {
// Scheduler warp manages tile assignment and pipeline progress for warps
Expand Down
Original file line number Diff line number Diff line change
Expand Up @@ -367,7 +367,7 @@ rht_gemm_device(MShape M, NShape N, KShape K, ClusterTileShape cluster_tile,
} else if (is_mma_warp) {
mma.accumulate_ = UMMA::ScaleOut::Zero;

tmem_allocator.allocate(TmemAllocator::Sm100TmemCapacityColumns, &shared_storage.tmem_base_ptr);
tmem_allocator.allocate(cute::TMEM::Sm100TmemCapacityColumns, &shared_storage.tmem_base_ptr);
__syncwarp();
tmem_allocation_result_barrier.arrive();
uint32_t tmem_base_ptr = shared_storage.tmem_base_ptr;
Expand Down Expand Up @@ -410,7 +410,7 @@ rht_gemm_device(MShape M, NShape N, KShape K, ClusterTileShape cluster_tile,
} while (tile_idx_m < tiles_in_m && tile_idx_n < tiles_in_n);
tmem_allocator.release_allocation_lock();
accumulator_pipeline.producer_tail(accumulator_pipe_producer_state);
tmem_allocator.free(tmem_base_ptr, TmemAllocator::Sm100TmemCapacityColumns);
tmem_allocator.free(tmem_base_ptr, cute::TMEM::Sm100TmemCapacityColumns);
} else if (is_epilogue_warp) {
const float global_amax_val = *global_amax;
static constexpr int FragmentSize = 256 / sizeof_bits_v<TC>;
Expand Down
Original file line number Diff line number Diff line change
Expand Up @@ -585,7 +585,8 @@ __global__ static void row_col_rht_gemm_device(

mma.accumulate_ = UMMA::ScaleOut::Zero;

tmem_allocator.allocate(TmemAllocator::Sm100TmemCapacityColumns, &shared_storage.tmem_base_ptr);
tmem_allocator.allocate(cute::TMEM::Sm100TmemCapacityColumns,
&shared_storage.tmem_base_ptr);
__syncwarp();
tmem_allocation_result_barrier.arrive();
uint32_t tmem_base_ptr = shared_storage.tmem_base_ptr;
Expand Down Expand Up @@ -633,7 +634,7 @@ __global__ static void row_col_rht_gemm_device(
} while (scheduler.is_valid());
tmem_allocator.release_allocation_lock();
accumulator_pipeline.producer_tail(accumulator_pipe_producer_state);
tmem_allocator.free(tmem_base_ptr, TmemAllocator::Sm100TmemCapacityColumns);
tmem_allocator.free(tmem_base_ptr, cute::TMEM::Sm100TmemCapacityColumns);
}
} else if(is_sched_warp) {
cutlass::arch::warpgroup_reg_dealloc<32>();
Expand Down
Loading